@@ -1,4 +1,4 @@
-# Copyright (c) 2013-2017 Christian Geier et al.
+# Copyright (c) 2013-2021 khal contributors
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -161,12 +161,33 @@ class Event(object):
             start = dt.datetime.combine(start, dt.time.min)
 
         if isinstance(other_start, dt.date) and not isinstance(other_start, dt.datetime):
-            other_start = dt.datetime.combine(other_start, dt.time.max)
+            other_start = dt.datetime.combine(other_start, dt.time.min)
 
         start = start.replace(tzinfo=None)
         other_start = other_start.replace(tzinfo=None)
+
+        if start == other_start:
+            end = self.end_local
+            other_end = other.end_local
+            if isinstance(end, dt.date) and not isinstance(end, dt.datetime):
+                end = dt.datetime.combine(end, dt.time.min)
+
+            if isinstance(other_end, dt.date) and not isinstance(other_end, dt.datetime):
+                other_end = dt.datetime.combine(other_end, dt.time.min)
+
+            end = end.replace(tzinfo=None)
+            other_end = other_end.replace(tzinfo=None)
+
+            if end == other_end:
+                return self.summary < other.summary
+
+            try:
+                return end < other_end
+            except TypeError:
+                raise ValueError('Cannot compare events {} and {}'.format(end, other_end))
+
         try:
-            return start <= other_start
+            return start < other_start
         except TypeError:
             raise ValueError('Cannot compare events {} and {}'.format(start, other_start))
 
@@ -301,6 +322,18 @@ class Event(object):
         else:
             return email
 
+    @property
+    def url(self):
+        if 'URL' not in self._vevents[self.ref]:
+            return ''
+        return self._vevents[self.ref]['URL']
+
+    def update_url(self, url):
+        if url:
+            self._vevents[self.ref]['URL'] = url
+        else:
+            self._vevents[self.ref].pop('URL')
+
     @staticmethod
     def _create_calendar():
         """
@@ -597,6 +630,7 @@ class Event(object):
         attributes["all-day"] = allday
         attributes["categories"] = self.categories
         attributes['uid'] = self.uid
+        attributes['url'] = self.url
 
         if "calendars" in env and self.calendar in env["calendars"]:
             cal = env["calendars"][self.calendar]
