@@ -1,4 +1,4 @@
-# Copyright (c) 2013-2017 Christian Geier et al.
+# Copyright (c) 2013-2021 khal contributors
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -255,7 +255,10 @@ class EventListBox(urwid.ListBox):
 
     @property
     def focus_event(self):
-        return self.focus.original_widget
+        if self.focus is None:
+            return None
+        else:
+            return self.focus.original_widget
 
     def refresh_titles(self, min_date, max_date, everything):
         """Refresh only the currently focused event's title
@@ -738,7 +741,7 @@ class EventColumn(urwid.WidgetWrap):
             self.pane.window.loop.start()
             if text is None:
                 return
-            # KeyErrors can occurr here when we destroy DTSTART,
+            # KeyErrors can occur here when we destroy DTSTART,
             # otherwise, even broken .ics files seem to be no problem
             new_event = Event.fromString(
                 text,
@@ -871,6 +874,8 @@ class EventColumn(urwid.WidgetWrap):
         if not self.pane.collection.writable_names:
             self.pane.window.alert(('alert', 'No writable calendar.'))
             return
+        if date is None:
+            date = dt.datetime.now()
         if end is None:
             start = dt.datetime.combine(date, dt.time(dt.datetime.now().hour))
             end = start + dt.timedelta(minutes=60)
@@ -955,6 +960,9 @@ class EventDisplay(urwid.WidgetWrap):
         if event.categories != '':
             lines.append(urwid.Text('Categories: ' + event.categories))
 
+        if event.url != '':
+            lines.append(urwid.Text('URL: ' + event.url))
+
         # start and end time/date
         if event.allday:
             startstr = event.start_local.strftime(self._conf['locale']['dateformat'])
